==> ode-python-0.0.4.tar.gz: ode-python-0.0.4/README.md <==
ode-python [![Build Status](https://travis-ci.com/qoosky/ode-python.svg?branch=master)](https://travis-ci.com/qoosky/ode-python)
==================
This is yet another Python binding of [Open Dynamics Engine (ODE)](https://www.ode.org/).

	pip install ode-python

Please note that ODE and Drawstuff are not included in this library.

To install ODE on debian for example:

	apt install libode-dev

Code samples are available in `test` directory.

![Bounce](https://github.com/qoosky/ode-python/blob/master/images/bounce.png)


License
------------------
The MIT License (MIT)

Copyright (c) 2020 Qoosky

Permission is hereby granted, free of charge, to any person obtaining a copy
of this software and associated documentation files (the "Software"), to deal
in the Software without restriction, including without limitation the rights
to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
copies of the Software, and to permit persons to whom the Software is
furnished to do so, subject to the following conditions:

The above copyright notice and this permission notice shall be included in all
copies or substantial portions of the Software.

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
SOFTWARE.

==> ode-python-0.0.5.tar.gz: ode-python-0.0.5/README.md <==
ode-python [![Build Status](https://travis-ci.com/qoosky/ode-python.svg?branch=master)](https://travis-ci.com/qoosky/ode-python)
==================
This is yet another Python binding of [Open Dynamics Engine (ODE)](https://www.ode.org/).

	pip install ode-python

Please note that ODE and Drawstuff are not included in this library.

To install ODE on debian for example:

	apt install libode-dev

Code samples are available in `test` directory.

![Bounce](https://raw.githubusercontent.com/qoosky/ode-python/master/images/bounce.png)


License
------------------
The MIT License (MIT)

Copyright (c) 2020 Qoosky

Permission is hereby granted, free of charge, to any person obtaining a copy
of this software and associated documentation files (the "Software"), to deal
in the Software without restriction, including without limitation the rights
to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
copies of the Software, and to permit persons to whom the Software is
furnished to do so, subject to the following conditions:

The above copyright notice and this permission notice shall be included in all
copies or substantial portions of the Software.

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
SOFTWARE.
